@@ -1,5 +1,6 @@
 from flask.json import JSONEncoder
 from datetime import datetime
+from werkzeug.http import http_date
 from bson import ObjectId, Timestamp
 from .uorm.models.base_model import BaseModel
 from .uorm.db import ObjectsCursor
@@ -7,7 +8,6 @@ import simplejson
 
 
 def default(o):  # pylint: disable=method-hidden
-
     if isinstance(o, ObjectId):
         return str(o)
     if isinstance(o, Timestamp):
@@ -17,7 +17,9 @@ def default(o):  # pylint: disable=method-hidden
     if isinstance(o, BaseModel):
         return o.to_dict()
     if isinstance(o, datetime):
-        return o.isoformat()
+        return http_date(o.utctimetuple())
+    if isinstance(o, date):
+        return http_date(o.timetuple())
     raise TypeError(f"{repr(o)} is not JSON serializable")
 
 
@@ -27,3 +29,4 @@ def dumps(o, default=default, **kwargs):
 
 def loads(text: str, **kwargs):
     return simplejson.loads(text, **kwargs)
+
